@@ -21,6 +21,7 @@
 #include <osi.h>
 
 #include "afsd.h"
+#include "cm_btree.h"
 
 /*extern void afsi_log(char *pattern, ...);*/
 
@@ -207,6 +208,20 @@ long cm_RecycleSCache(cm_scache_t *scp, afs_int32 flags)
      * while we hold the global refcount lock.
      */
     cm_FreeAllACLEnts(scp);
+
+#ifdef USE_BPLUS
+    /* destroy directory Bplus Tree */
+    if (scp->dirBplus) {
+        LARGE_INTEGER start, end;
+        QueryPerformanceCounter(&start);
+        bplus_free_tree++;
+        freeBtree(scp->dirBplus);
+        scp->dirBplus = NULL;
+        QueryPerformanceCounter(&end);
+
+        bplus_free_time += (end.QuadPart - start.QuadPart);
+    }
+#endif
     return 0;
 }
 
@@ -299,6 +314,9 @@ cm_scache_t *cm_GetNewSCache(void)
     scp->magic = CM_SCACHE_MAGIC;
     lock_InitializeMutex(&scp->mx, "cm_scache_t mutex");
     lock_InitializeRWLock(&scp->bufCreateLock, "cm_scache_t bufCreateLock");
+#ifdef USE_BPLUS
+    lock_InitializeRWLock(&scp->dirlock, "cm_scache_t dirlock");
+#endif
     scp->serverLock = -1;
 
     /* and put it in the LRU queue */
@@ -456,18 +474,26 @@ void
 cm_SuspendSCache(void)
 {
     cm_scache_t * scp;
+    time_t now;
 
-    cm_GiveUpAllCallbacksAllServers();
+    cm_GiveUpAllCallbacksAllServers(TRUE);
+
+    /* 
+     * After this call all servers are marked down.
+     * Do not clear the callbacks, instead change the
+     * expiration time so that the callbacks will be expired
+     * when the servers are marked back up.  However, we
+     * want the callbacks to be preserved as long as the 
+     * servers are down.  That way if the machine resumes
+     * without network, the stat cache item will still be
+     * considered valid.
+     */
+    now = osi_Time();
 
     lock_ObtainWrite(&cm_scacheLock);
-    for ( scp = cm_data.allSCachesp; scp;
-          scp = scp->allNextp ) {
-        if (scp->cbServerp) {
-            cm_PutServer(scp->cbServerp);
-            scp->cbServerp = NULL;
-        }
-        scp->cbExpires = 0;
-        scp->flags &= ~CM_SCACHEFLAG_CALLBACK;
+    for ( scp = cm_data.allSCachesp; scp; scp = scp->allNextp ) {
+        if (scp->cbServerp)
+            scp->cbExpires = now+1;
     }
     lock_ReleaseWrite(&cm_scacheLock);
 }
@@ -494,12 +520,19 @@ cm_ShutdownSCache(void)
         scp->cbExpires = 0;
         scp->flags &= ~CM_SCACHEFLAG_CALLBACK;
 
+#ifdef USE_BPLUS
+        if (scp->dirBplus)
+            freeBtree(scp->dirBplus);
+        scp->dirBplus = NULL;
+        scp->dirDataVersion = -1;
+        lock_FinalizeRWLock(&scp->dirlock);
+#endif
         lock_FinalizeMutex(&scp->mx);
         lock_FinalizeRWLock(&scp->bufCreateLock);
     }
     lock_ReleaseWrite(&cm_scacheLock);
 
-    cm_GiveUpAllCallbacksAllServers();
+    cm_GiveUpAllCallbacksAllServers(FALSE);
 
     return cm_dnlcShutdown();
 }
@@ -523,7 +556,9 @@ void cm_InitSCache(int newFile, long maxSCaches)
                   scp = scp->allNextp ) {
                 lock_InitializeMutex(&scp->mx, "cm_scache_t mutex");
                 lock_InitializeRWLock(&scp->bufCreateLock, "cm_scache_t bufCreateLock");
-
+#ifdef USE_BPLUS
+                lock_InitializeRWLock(&scp->dirlock, "cm_scache_t dirlock");
+#endif
                 scp->cbServerp = NULL;
                 scp->cbExpires = 0;
                 scp->fileLocksH = NULL;
@@ -537,6 +572,10 @@ void cm_InitSCache(int newFile, long maxSCaches)
                 scp->openShares = 0;
                 scp->openExcls = 0;
                 scp->waitCount = 0;
+#ifdef USE_BPLUS
+                scp->dirBplus = NULL;
+                scp->dirDataVersion = -1;
+#endif
                 scp->flags &= ~CM_SCACHEFLAG_WAITING;
             }
         }
