@@ -99,7 +99,8 @@ void Display_PopulateGroupList (void)
          GetString (szQuerying, IDS_QUERYING_LONG);
          SetDlgItemText (hDlg, IDC_GROUPS_TITLE, szQuerying);
 
-         Display_StartWorking();         GetDlgItemText (hDlg, IDC_GROUPS_PATTERN, g.szPatternGroups, cchNAME);
+         Display_StartWorking();
+         GetDlgItemText (hDlg, IDC_GROUPS_PATTERN, g.szPatternGroups, cchNAME);
          StartTask (taskUPD_GROUPS, g.hMain);
          }
       }
@@ -540,7 +541,7 @@ BOOL Display_HandleColumnNotify (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp, LPVI
 {
    if (msg == WM_NOTIFY)
       {
-      HWND hList = GetDlgItem (hDlg, ((LPNMHDR)lp)->idFrom);
+      HWND hList = GetDlgItem (hDlg, (int)((LPNMHDR)lp)->idFrom);
       if (fIsFastList (hList))
          {
          switch (((LPNMHDR)lp)->code)
@@ -571,7 +572,7 @@ BOOL Display_HandleColumnNotify (HWND hDlg, UINT msg, WPARAM wp, LPARAM lp, LPVI
 }
 
 
-BOOL CALLBACK Display_GetItemText (HWND hList, LPFLN_GETITEMTEXT_PARAMS pfln, DWORD dwCookie)
+BOOL CALLBACK Display_GetItemText (HWND hList, LPFLN_GETITEMTEXT_PARAMS pfln, UINT_PTR dwCookie)
 { 
    LPVIEWINFO lpvi = (LPVIEWINFO)dwCookie;
    ASID idObject = (ASID)(pfln->item.lParam);
