@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/auth/cellconfig.c,v 1.47.2.7 2006/12/28 20:37:21 shadow Exp $");
+    ("$Header: /cvs/openafs/src/auth/cellconfig.c,v 1.47.2.9 2007/07/03 00:35:14 jaltman Exp $");
 
 #include <afs/stds.h>
 #include <afs/pthread_glock.h>
@@ -534,7 +534,7 @@ afsconf_OpenInternal(register struct afsconf_dir *adir, char *cell,
     char tbuffer[256], tbuf1[256];
     struct stat tstat;
 
-    /* figure out the cell name */
+    /* figure out the local cell name */
 #ifdef AFS_NT40_ENV
     i = GetCellNT(adir);
 #else
@@ -860,6 +860,7 @@ afsconf_GetAfsdbInfo(char *acellName, char *aservice,
     char host[256];
     int server_num = 0;
     int minttl = 0;
+    int try_init = 0;
 
     /* The resolver isn't always MT-safe.. Perhaps this ought to be
      * replaced with a more fine-grained lock just for the resolver
@@ -886,8 +887,8 @@ afsconf_GetAfsdbInfo(char *acellName, char *aservice,
        UNLOCK_GLOBAL_MUTEX;
     }
     if (len < 0) {
-	if (try < 1) {
-	    try++;
+	if (try_init < 1) {
+	    try_init++;
 	    res_init();
 	    goto retryafsdb;
 	}
