@@ -19,7 +19,6 @@
 #define AFS_PPC_LINUX22_ENV    1
 #define AFS_PPC_LINUX24_ENV    1
 #define AFS_PPC_LINUX26_ENV 1
-#define AFS_NONFSTRANS 1
 
 #define AFS_MOUNT_AFS "afs"	/* The name of the filesystem type. */
 #define AFS_SYSCALL 137
@@ -29,9 +28,7 @@
 #define AFS_NAMEI_ENV     1	/* User space interface to file system */
 
 #if defined(__KERNEL__) && !defined(KDUMP_KERNEL)
-#include <linux/threads.h>
 
-#include <linux/config.h>
 #ifdef CONFIG_SMP
 #ifndef AFS_SMP
 #define AFS_SMP 1
@@ -76,6 +73,12 @@
 #endif
 #endif /* KERNEL */
 
+#ifdef __GLIBC__
+#if (__GLIBC__ > 2) || (__GLIBC__ == 2 && __GLIBC_MINOR__ > 3)
+#define USE_UCONTEXT
+#endif
+#endif
+
 #endif /* AFS_PARAM_H */
 
 #else /* !defined(UKERNEL) */
