@@ -16,7 +16,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/kauth/krb_udp.c,v 1.22 2003/07/15 23:15:17 shadow Exp $");
+    ("$Header: /cvs/openafs/src/kauth/krb_udp.c,v 1.23.14.1 2007/04/10 18:39:52 shadow Exp $");
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -84,7 +84,6 @@ struct packet {
     char data[MAX_PKT_LEN];
 };
 
-extern struct kadstats dynamic_statistics;
 extern char *lastOperation;
 extern char lrealm[];
 
@@ -736,12 +735,12 @@ process_udp_auth(ksoc, pkt)
     if (code) {
 	if (code == KANOENT) {
 	    code = KERB_ERR_PRINCIPAL_UNKNOWN;
-	    err_packet(ksoc, pkt, code, (char *)error_message(code));
+	    err_packet(ksoc, pkt, code, (char *)afs_error_message(code));
 	} else if (code == KAPWEXPIRED) {
 	    code = KERB_ERR_NAME_EXP;
 	    err_packet(ksoc, pkt, code, "password has expired");
 	} else
-	    err_packet(ksoc, pkt, code, (char *)error_message(code));
+	    err_packet(ksoc, pkt, code, (char *)afs_error_message(code));
     }
     return 0;
 }
@@ -785,7 +784,7 @@ process_udp_appl(ksoc, pkt)
     if (code) {
 	if (code == KANOENT)
 	    code = KERB_ERR_PRINCIPAL_UNKNOWN;
-	err_packet(ksoc, pkt, code, (char *)error_message(code));
+	err_packet(ksoc, pkt, code, (char *)afs_error_message(code));
 	return -1;
     }
     return 0;
