@@ -11,7 +11,7 @@
 #include <afs/param.h>
 
 RCSID
-    ("$Header: /cvs/openafs/src/ptserver/testpt.c,v 1.13 2003/12/07 22:49:35 jaltman Exp $");
+    ("$Header: /cvs/openafs/src/ptserver/testpt.c,v 1.14.14.2 2007/08/11 23:41:37 jaltman Exp $");
 
 #include <ctype.h>
 #include <errno.h>
@@ -49,15 +49,15 @@ RCSID
 #include "ptclient.h"
 #include "pterror.h"
 #include <afs/afsutil.h>
+#include <afs/com_err.h>
 
 static char *whoami = "testpr";
 static struct afsconf_dir *conf;	/* cell info, set by MyBeforeProc */
 static char conf_dir[100];
 static char lcell[MAXCELLCHARS];
 
-ListUsedIds(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+int
+ListUsedIds(struct cmd_syndesc *as, char *arock)
 {
     afs_int32 code;
     namelist lnames;
@@ -79,7 +79,7 @@ ListUsedIds(as, arock)
 
     code = pr_Initialize(1, conf_dir, NULL);
     if (code) {
-	com_err(whoami, code, "initializing pruser");
+	afs_com_err(whoami, code, "initializing pruser");
 	exit(1);
     }
     if (startId < 0) {
@@ -87,7 +87,7 @@ ListUsedIds(as, arock)
 	code = pr_ListMaxGroupId(&maxId);
 	if (code) {
 	  bad_max:
-	    com_err(whoami, code, "getting maximum id");
+	    afs_com_err(whoami, code, "getting maximum id");
 	    exit(2);
 	}
 	if (startId < maxId) {
@@ -133,7 +133,7 @@ ListUsedIds(as, arock)
 	lids.idlist_len = i;
 	code = pr_IdToName(&lids, &lnames);
 	if (code) {
-	    com_err(whoami, code, "converting id to name");
+	    afs_com_err(whoami, code, "converting id to name");
 	    exit(2);
 	}
 	for (j = 0; j < lnames.namelist_len; j++) {
@@ -184,9 +184,7 @@ afs_int32 *groupOwners;		/* ids of owners of groups */
 int nUsers, nGroups, nAdds, nRems, nUDels, nGDels;
 
 int
-IdCmp(a, b)
-     afs_int32 *a;
-     afs_int32 *b;
+IdCmp(afs_int32 *a, afs_int32 *b)
 {
     if (*a > *b) {
 	return 1;
@@ -198,16 +196,13 @@ IdCmp(a, b)
 }
 
 static int
-sqr(n)
-     int n;
+sqr(int n)
 {
     return n * n;
 }
 
 static int
-GetGroupLimit(N, x)
-     int N;
-     int x;
+GetGroupLimit(int N, int x)
 {
     int y;
     double sqrt();
@@ -239,8 +234,7 @@ GetGroupLimit(N, x)
 }
 
 void
-CreateUser(u)
-     int u;
+CreateUser(int u)
 {
     afs_int32 code;
     char name[16];
@@ -262,7 +256,7 @@ CreateUser(u)
 		}
 	    }
 	}
-	com_err(whoami, code, "couldn't create %s", name);
+	afs_com_err(whoami, code, "couldn't create %s", name);
 	exit(12);
     }
   done:
@@ -278,8 +272,7 @@ CreateUser(u)
 }
 
 void
-CreateGroup(g)
-     int g;
+CreateGroup(int g)
 {
     afs_int32 code;
     char name[16];
@@ -315,14 +308,14 @@ CreateGroup(g)
     }
 
     sprintf(name, "%s:%s%d", ownerName, createPrefix, g);
-    code = ubik_Call(PR_NewEntry, pruclient, 0, name, PRGRP, owner, &id);
+    code = ubik_PR_NewEntry(pruclient, 0, name, PRGRP, owner, &id);
     if (code) {
 	if (code == PREXIST) {
 	    code = pr_Delete(name);
 	    if (code == 0) {
 		nGDels++;
 		code =
-		    ubik_Call(PR_NewEntry, pruclient, 0, name, PRGRP, owner,
+		    ubik_PR_NewEntry(pruclient, 0, name, PRGRP, owner,
 			      &id);
 		if (code == 0) {
 		    if (verbose)
@@ -331,7 +324,7 @@ CreateGroup(g)
 		}
 	    }
 	}
-	com_err(whoami, code, "couldn't create %s w/ owner=%d", name, owner);
+	afs_com_err(whoami, code, "couldn't create %s w/ owner=%d", name, owner);
 	exit(13);
     }
   done:
@@ -347,8 +340,7 @@ CreateGroup(g)
 }
 
 int
-DeleteRandomId(list)
-     afs_int32 *list;
+DeleteRandomId(afs_int32 *list)
 {
     afs_int32 code;
     afs_int32 id;
@@ -359,9 +351,9 @@ DeleteRandomId(list)
     for (j = 0; j < number; j++) {	/* find an undeleted id */
 	m = (k + j) % number;
 	if (id = list[m]) {
-	    code = ubik_Call(PR_Delete, pruclient, 0, id);
+	    code = ubik_PR_Delete(pruclient, 0, id);
 	    if (code) {
-		com_err(whoami, code, "Couldn't delete %di", id);
+		afs_com_err(whoami, code, "Couldn't delete %di", id);
 		exit(22);
 	    }
 	    list[m] = 0;
@@ -376,8 +368,7 @@ DeleteRandomId(list)
 }
 
 void
-AddUser(u, g)
-     int u, g;
+AddUser(int u, int g)
 {
     afs_int32 code;
     afs_int32 ui, gi;
@@ -388,9 +379,9 @@ AddUser(u, g)
 	CreateGroup(g);
     ui = users[u];
     gi = groups[g];
-    code = ubik_Call(PR_AddToGroup, pruclient, 0, ui, gi);
+    code = ubik_PR_AddToGroup(pruclient, 0, ui, gi);
     if (code) {
-	com_err(whoami, code, "couldn't add %d to %d", ui, gi);
+	afs_com_err(whoami, code, "couldn't add %d to %d", ui, gi);
 	exit(14);
     }
     if (verbose)
@@ -400,17 +391,16 @@ AddUser(u, g)
 }
 
 void
-RemUser(u, g)
-     int u, g;
+RemUser(int u, int g)
 {
     afs_int32 code;
     afs_int32 ui, gi;
 
     ui = users[u];
     gi = groups[g];
-    code = ubik_Call(PR_RemoveFromGroup, pruclient, 0, ui, gi);
+    code = ubik_PR_RemoveFromGroup(pruclient, 0, ui, gi);
     if (code) {
-	com_err(whoami, code, "couldn't remove %d from %d", ui, gi);
+	afs_com_err(whoami, code, "couldn't remove %d from %d", ui, gi);
 	exit(14);
     }
     if (verbose)
@@ -419,9 +409,8 @@ RemUser(u, g)
     nRems++;
 }
 
-TestManyMembers(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+int
+TestManyMembers(struct cmd_syndesc *as, char *arock)
 {
     char *filled;		/* users filled up */
     char *cleaned;		/* users cleaned up */
@@ -436,7 +425,7 @@ TestManyMembers(as, arock)
 
     code = pr_Initialize(1, conf_dir, NULL);
     if (code) {
-	com_err(whoami, code, "initializing pruser");
+	afs_com_err(whoami, code, "initializing pruser");
 	exit(1);
     }
     /* get name of person running command */
@@ -451,7 +440,7 @@ TestManyMembers(as, arock)
 	    exit(2);
 	code = ktc_GetToken(&afs, &token, sizeof(token), &user);
 	if (code) {
-	    com_err(whoami, code, "getting afs tokens");
+	    afs_com_err(whoami, code, "getting afs tokens");
 	    exit(3);
 	}
 	if (strlen(user.instance) > 0) {
@@ -463,7 +452,7 @@ TestManyMembers(as, arock)
 	    callerId = atoi(user.name + 7);
 	    code = pr_SIdToName(callerId, callerName);
 	    if (code) {
-		com_err(whoami, code, "call get name for id %d", callerId);
+		afs_com_err(whoami, code, "call get name for id %d", callerId);
 		exit(6);
 	    }
 	} else {
@@ -477,7 +466,7 @@ TestManyMembers(as, arock)
 	    callerId = 0;
 	    code = pr_CreateUser(callerName, &callerId);
 	    if (code) {
-		com_err(whoami, code, "can't create caller %s", callerName);
+		afs_com_err(whoami, code, "can't create caller %s", callerName);
 		exit(5);
 	    }
 	    printf("Creating caller %s (%di)\n", callerName, callerId);
@@ -485,7 +474,7 @@ TestManyMembers(as, arock)
 	/* else */
 #endif
 	if (code) {
-	    com_err(whoami, code, "can't find caller %s", callerName);
+	    afs_com_err(whoami, code, "can't find caller %s", callerName);
 	    exit(6);
 	} else
 	    printf("Assuming caller is %s (%di)\n", callerName, callerId);
@@ -611,7 +600,7 @@ TestManyMembers(as, arock)
 		proc = PR_GetCPS;
 	    code = ubik_Call(proc, pruclient, 0, ui, &alist, &over);
 	    if (code) {
-		com_err(whoami, code,
+		afs_com_err(whoami, code,
 			"getting membership list of (%di) using %s", ui,
 			((proc == PR_GetCPS) ? "GetCPR" : "ListElements"));
 		exit(24);
@@ -667,9 +656,9 @@ TestManyMembers(as, arock)
 		}
 #define GETOWNED(xlist,xid) \
   (xlist).prlist_val = 0; (xlist).prlist_len = 0; \
-  code = ubik_Call (PR_ListOwned, pruclient, 0, (xid), &(xlist), &over); \
+  code = ubik_PR_ListOwned(pruclient, 0, (xid), &(xlist), &over); \
   if (code) { \
-      com_err (whoami, code, "getting owner list of (%di)", (xid)); \
+      afs_com_err (whoami, code, "getting owner list of (%di)", (xid)); \
       exit (23); } \
   if (over) \
       { fprintf (stderr, "membership of id %di too long\n", (xid)); }
@@ -736,11 +725,10 @@ TestManyMembers(as, arock)
 /* Converts a byte string to ascii.  Return the number of unconverted bytes. */
 
 static int
-ka_ConvertBytes(ascii, alen, bs, bl)
-     char *ascii;		/* output buffer */
-     int alen;			/* buffer length */
-     char bs[];			/* byte string */
-     int bl;			/* number of bytes */
+ka_ConvertBytes(char *ascii,		/* output buffer */
+		int alen,		/* buffer length */
+		char bs[],		/* byte string */
+		int bl)			/* number of bytes */
 {
     int i;
     unsigned char c;
@@ -778,9 +766,8 @@ ka_ConvertBytes(ascii, alen, bs, bl)
  *     must be correct.
  */
 
-TestPrServ(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+int
+TestPrServ(struct cmd_syndesc *as, char *arock)
 {
     afs_int32 id;
     char name[PR_MAXNAMELEN + 1];
@@ -792,7 +779,7 @@ TestPrServ(as, arock)
 
     code = pr_Initialize(1, conf_dir, NULL);
     if (code) {
-	com_err(whoami, code, "initializing pruser");
+	afs_com_err(whoami, code, "initializing pruser");
 	exit(1);
     }
 
@@ -803,7 +790,7 @@ TestPrServ(as, arock)
     id = 0;
     code = pr_CreateUser(name, &id);
     if ((code != RXGEN_CC_MARSHAL) && (code != PRBADNAM)) {
-	com_err(whoami, code, "succeeded creating %s", name);
+	afs_com_err(whoami, code, "succeeded creating %s", name);
 	exit(2);
     }
     name[i] = 0;
@@ -813,17 +800,17 @@ TestPrServ(as, arock)
 	fprintf(stderr, "group already exists, skipping\n");
 	pr_SNameToId(name, &id);
     } else if (code) {
-	com_err(whoami, code, "failed creating %s", name);
+	afs_com_err(whoami, code, "failed creating %s", name);
 	exit(3);
     }
     if ((code = pr_ListEntry(id, &ent))
 	|| (code = pr_SIdToName(ent.creator, creator))) {
-	com_err(whoami, code, "getting creator's name");
+	afs_com_err(whoami, code, "getting creator's name");
 	exit(5);
     }
     code = pr_DeleteByID(id);
     if (code) {
-	com_err(whoami, code, "deleting %s", name);
+	afs_com_err(whoami, code, "deleting %s", name);
 	exit(6);
     }
     /* now make sure the illegal chars are detected */
@@ -834,7 +821,7 @@ TestPrServ(as, arock)
 	    id = 0;
 	    code = pr_CreateUser(name, &id);
 	    if (code != PRBADNAM) {
-		com_err(whoami, code, "succeeded creating %s", name);
+		afs_com_err(whoami, code, "succeeded creating %s", name);
 		exit(8);
 	    }
 	}
@@ -856,12 +843,12 @@ TestPrServ(as, arock)
 	} else if (code) {
 	    char ascii[BUFSIZ];
 	    ka_ConvertBytes(ascii, sizeof(ascii), name, strlen(name));
-	    com_err(whoami, code, "failed creating %s", ascii);
+	    afs_com_err(whoami, code, "failed creating %s", ascii);
 	    exit(4);
 	}
 	code = pr_DeleteByID(id);
 	if (code) {
-	    com_err(whoami, code, "deleting %s", name);
+	    afs_com_err(whoami, code, "deleting %s", name);
 	    exit(7);
 	}
     }
@@ -873,7 +860,7 @@ TestPrServ(as, arock)
     id = 0;
     code = pr_CreateGroup(name, &id);
     if (code != PRNOENT) {	/* owner doesn't exist */
-	com_err(whoami, code, "succeeded creating %s", name);
+	afs_com_err(whoami, code, "succeeded creating %s", name);
 	exit(9);
     }
     name[0] = creator[0];	/* fix owner */
@@ -885,7 +872,7 @@ TestPrServ(as, arock)
 	    id = 0;
 	    code = pr_CreateGroup(name, creator, &id);
 	    if (code != PRBADNAM) {
-		com_err(whoami, code, "succeeded creating %s", name);
+		afs_com_err(whoami, code, "succeeded creating %s", name);
 		exit(10);
 	    }
 	}
@@ -906,12 +893,12 @@ TestPrServ(as, arock)
 	} else if (code) {
 	    char ascii[BUFSIZ];
 	    ka_ConvertBytes(ascii, sizeof(ascii), name, strlen(name));
-	    com_err(whoami, code, "failed creating %s", ascii);
+	    afs_com_err(whoami, code, "failed creating %s", ascii);
 	    exit(4);
 	}
 	code = pr_DeleteByID(id);
 	if (code) {
-	    com_err(whoami, code, "deleting %s", name);
+	    afs_com_err(whoami, code, "deleting %s", name);
 	    exit(7);
 	}
     }
@@ -926,9 +913,7 @@ static char tmp_cell_file[128] = "";
 static char tmp_noauth_file[128] = "";
 
 static int
-MyAfterProc(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+MyAfterProc(struct cmd_syndesc *as, char *arock)
 {
     if (strlen(tmp_conf_file))
 	unlink(tmp_conf_file);
@@ -942,9 +927,7 @@ MyAfterProc(as, arock)
 }
 
 static int
-MyBeforeProc(as, arock)
-     struct cmd_syndesc *as;
-     char *arock;
+MyBeforeProc(struct cmd_syndesc *as, char *arock)
 {
     afs_int32 code;
     int i;
@@ -1021,7 +1004,7 @@ MyBeforeProc(as, arock)
 		(unsigned long)getpid());
 	code = mkdir(tmp_conf_dir, 0777);
 	if ((code < 0) && (errno != EEXIST)) {
-	    com_err(whoami, errno, "can't create temporary afsconf dir: %s",
+	    afs_com_err(whoami, errno, "can't create temporary afsconf dir: %s",
 		    cdir);
 	    return errno;
 	}
@@ -1031,7 +1014,7 @@ MyBeforeProc(as, arock)
 	f = fopen(tmp_conf_file, "w");
 	if (f == 0) {
 	  cantcreate:
-	    com_err(whoami, errno, "can't create conf file %s",
+	    afs_com_err(whoami, errno, "can't create conf file %s",
 		    tmp_conf_file);
 	    return errno;
 	}
@@ -1044,7 +1027,7 @@ MyBeforeProc(as, arock)
 	}
 	if (fclose(f) == EOF) {
 	  cantclose:
-	    com_err(whoami, errno, "can't write to conf file %s",
+	    afs_com_err(whoami, errno, "can't write to conf file %s",
 		    tmp_conf_file);
 	    return errno;
 	}
@@ -1079,8 +1062,7 @@ MyBeforeProc(as, arock)
 }
 
 static void
-add_std_args(ts)
-     register struct cmd_syndesc *ts;
+add_std_args(register struct cmd_syndesc *ts)
 {
     cmd_Seek(ts, 12);
     cmd_AddParm(ts, "-confdir", CMD_SINGLE, CMD_OPTIONAL,
@@ -1102,9 +1084,8 @@ osi_audit()
 
 #include "AFS_component_version_number.c"
 
-main(argc, argv)
-     int argc;
-     char *argv[];
+int 
+main(int argc, char *argv[])
 {
     afs_int32 code;
     struct cmd_syndesc *ts;	/* ptr to parsed command line syntax */
@@ -1155,6 +1136,6 @@ main(argc, argv)
 
     code = cmd_Dispatch(argc, argv);
     if (code)
-	com_err(whoami, code, "calling cmd_Dispatch");
+	afs_com_err(whoami, code, "calling cmd_Dispatch");
     exit(code);
 }
