@@ -10,7 +10,8 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID("$Header: /cvs/openafs/src/sys/pagsh.c,v 1.7 2001/11/13 04:52:29 shadow Exp $");
+RCSID
+    ("$Header: /cvs/openafs/src/sys/pagsh.c,v 1.9.14.2 2007/07/10 20:29:34 shadow Exp $");
 
 #ifdef	AFS_AIX32_ENV
 #include <signal.h>
@@ -34,13 +35,12 @@ RCSID("$Header: /cvs/openafs/src/sys/pagsh.c,v 1.7 2001/11/13 04:52:29 shadow Ex
 
 extern afs_int32 setpag();
 
-int main(argc, argv)
-int argc;
-char **argv;
+int
+main(int argc, char *argv[])
 {
-	struct passwd *pwe;
-	int uid, gid;
-	char *shell = "/bin/sh";
+    struct passwd *pwe;
+    int uid, gid;
+    char *shell = "/bin/sh";
 
 #ifdef	AFS_AIX32_ENV
     /*
@@ -50,46 +50,55 @@ char **argv;
      * generated which, in many cases, isn't too useful.
      */
     struct sigaction nsa;
-    
+
     sigemptyset(&nsa.sa_mask);
     nsa.sa_handler = SIG_DFL;
     nsa.sa_flags = SA_FULLDUMP;
     sigaction(SIGSEGV, &nsa, NULL);
 #endif
-	gid = getgid();
-	uid = getuid();
-	pwe = getpwuid(uid);
-	if (pwe == 0) {
-		fprintf(stderr, "Intruder alert.\n");
-	} else {
+    gid = getgid();
+    uid = getuid();
+    pwe = getpwuid(uid);
+    if (pwe == 0) {
+	fprintf(stderr, "Intruder alert.\n");
+    } else {
 /*		shell = pwe->pw_shell; */
-	}
-	if (setpag() == -1) {
-		perror("setpag");
-	}
+    }
+    if (setpag() == -1) {
+	perror("setpag");
+    }
 #ifdef AFS_KERBEROS_ENV
- 	ktc_newpag();
+    ktc_newpag();
 #endif
-	(void) setuid(uid);
-	(void) setgid(gid);
-	argv[0] = shell;
-	execvp(shell, argv);
-	perror(shell);
-	fprintf(stderr, "No shell\n");
-	exit(1);
+    (void)setuid(uid);
+    (void)setgid(gid);
+    argv[0] = shell;
+    execvp(shell, argv);
+    perror(shell);
+    fprintf(stderr, "No shell\n");
+    exit(1);
 }
 
 
 #ifdef AFS_KERBEROS_ENV
 /* stolen from auth/ktc.c */
 
-static afs_uint32 curpag()
+static afs_uint32
+curpag(void)
 {
+#if defined(AFS_AIX51_ENV)
+    afs_int32 pag;
+
+    if (kcred_getpag(cred, PAG_AFS, &pag) < 0 || pag == 0)
+        pag = NOPAG;
+    return pag;
+#else
     afs_uint32 groups[NGROUPS_MAX];
     afs_uint32 g0, g1;
     afs_uint32 h, l, ret;
 
-    if (getgroups(sizeof groups/sizeof groups[0], groups) < 2) return 0;
+    if (getgroups(sizeof groups / sizeof groups[0], groups) < 2)
+	return 0;
 
     g0 = groups[0] & 0xffff;
     g1 = groups[1] & 0xffff;
@@ -107,45 +116,55 @@ static afs_uint32 curpag()
 	    return -1;
     }
     return -1;
+#endif
 }
 
-ktc_newpag()
+int
+ktc_newpag(void)
 {
     extern char **environ;
 
     afs_uint32 pag;
     struct stat sbuf;
     char fname[256], *prefix = "/ticket/";
+    char fname5[256], *prefix5 = "FILE:/ticket/krb5cc_";
     int numenv;
     char **newenv, **senv, **denv;
 
     if (stat("/ticket", &sbuf) == -1) {
 	prefix = "/tmp/tkt";
+	prefix5 = "FILE:/tmp/krb5cc_";
     }
 
     pag = curpag() & 0xffffffff;
     if (pag == -1) {
 	sprintf(fname, "%s%d", prefix, getuid());
-    }
-    else {
+	sprintf(fname5, "%s%d", prefix5, getuid());
+    } else {
 	sprintf(fname, "%sp%ld", prefix, pag);
+	sprintf(fname5, "%sp%ld", prefix5, pag);
     }
 /*    ktc_set_tkt_string(fname); */
 
-    for (senv=environ, numenv=0; *senv; senv++) numenv++;
-    newenv = (char **)malloc((numenv+2) * sizeof(char *));
+    for (senv = environ, numenv = 0; *senv; senv++)
+	numenv++;
+    newenv = (char **)malloc((numenv + 2) * sizeof(char *));
 
-    for (senv=environ, denv=newenv; *senv; *senv++) {
-	if (strncmp(*senv, "KRBTKFILE=", 10) != 0) *denv++ = *senv;
+    for (senv = environ, denv = newenv; *senv; *senv++) {
+	if (strncmp(*senv, "KRBTKFILE=", 10) != 0 &&
+		strncmp(*senv, "KRB5CCNAME=", 11) != 0)
+	    *denv++ = *senv;
     }
 
-    *denv = malloc(10 + strlen(fname) + 1);
+    *denv = malloc(10+11 + strlen(fname) + strlen(fname5) + 2);
     strcpy(*denv, "KRBTKFILE=");
     strcat(*denv, fname);
+    *(denv+1) = *denv + strlen(*denv) + 1;
+    denv++;
+    strcpy(*denv, "KRB5CCNAME=");
+    strcat(*denv, fname5);
     *++denv = 0;
     environ = newenv;
 }
 
 #endif
-
-
